'*********************************************************
'
' Copyright (c) Microsoft. All rights reserved.
'
'*********************************************************

Imports CustomTemperatureSensor

Imports System

Namespace SDKTemplate
    Partial Public Class MainPage
        Inherits SDKTemplate.Common.LayoutAwarePage
        ' Change the string below to reflect the name of your sample.
        ' This is used on the main page as the title of the sample.
        Public Const FEATURE_NAME As String = "Custom Temperature Sensor"

        ' Change the array below to reflect the name of your scenarios.
        ' This will be used to populate the list of scenarios on the main page with
        ' which the user will choose the specific scenario that they are interested in.
        ' These should be in the form: "Navigating to a web page".
        ' The code in MainPage will take care of turning this into: "1) Navigating to a web page"
        Private scenarios As New Collections.Generic.List(Of Scenario)() From
    {New Scenario() With {.Title = "Connect to sensor", .ClassType = GetType(DeviceConnect)},
        New Scenario() With {.Title = "Get temperature data", .ClassType = GetType(InputReportEvents)},
            New Scenario() With {.Title = "Set report interval", .ClassType = GetType(ReportInterval)}}
    End Class

    Public Class Scenario
        Public Property Title() As String

        Public Property ClassType() As Type

        Public Overrides Function ToString() As String
            Return Title
        End Function
    End Class
End Namespace

Namespace CustomTemperatureSensor
    Public Enum DeviceType
        CustomSensor
        Any ' Can be any device
        None
    End Enum

    Public Class OnDeviceConnectedEventArgs
        'INSTANT VB NOTE: The variable isDeviceSuccessfullyConnected was renamed since Visual Basic does not allow class members with the same name:
        Private isDeviceSuccessfullyConnected_Renamed As Boolean
        'INSTANT VB NOTE: The variable deviceInformation was renamed since Visual Basic does not allow class members with the same name:
        Private deviceInformation_Renamed As Windows.Devices.Enumeration.DeviceInformation

        Public Sub New(ByVal isDeviceSuccessfullyConnected As Boolean, ByVal deviceInformation As Windows.Devices.Enumeration.DeviceInformation)
            Me.isDeviceSuccessfullyConnected_Renamed = isDeviceSuccessfullyConnected
            Me.deviceInformation_Renamed = deviceInformation
        End Sub

        Public ReadOnly Property IsDeviceSuccessfullyConnected() As Boolean
            Get
                Return isDeviceSuccessfullyConnected_Renamed
            End Get
        End Property

        Public ReadOnly Property DeviceInformation() As Windows.Devices.Enumeration.DeviceInformation
            Get
                Return deviceInformation_Renamed
            End Get
        End Property
    End Class

    Public Class DeviceProperties
        Public Const DeviceInstanceId As String = "System.Devices.DeviceInstanceId"
    End Class

    ''' <summary>
    '''          0x06,0x55,0xFF,     //HID_USAGE_PAGE_VENDOR_DEFINED
    '''          0x09,0xA5,          //HID_USAGE (vendor_defined)
    '''
    '''          0xA1,0x01,          //HID_COLLECTION(Application),
    '''
    '''          // Input report (device-transmits)
    '''          0x09,0xA7,          //HID_USAGE (vendor_defined)
    '''          0x15,0x00,          //HID_LOGICAL_MIN_8(0), // Minimum temp is 0 degrees F
    '''          0x25,0x96,          //HID_LOGICAL_MAX_8(1), // Max supported temp is 150 degrees F
    '''          0x75,0x08,          //HID_REPORT_SIZE(8),
    '''          0x95,0x01,          //HID_REPORT_COUNT(1),
    '''          0x81,0x02,          //HID_INPUT(Data_Var_Abs),
    '''
    '''          0x09,0xA8,          //HID_USAGE (vendor_defined)
    '''          0x15,0x4B,          //HID_LOGICAL_MIN_8(75),   // minimum 75 milliseconds
    '''          0x25,0xFF,          //HID_LOGICAL_MAX_8(255),  // maximum 255 milliseconds
    '''          0x75,0x08,          //HID_REPORT_SIZE(8), 
    '''          0x95,0x01,          //HID_REPORT_COUNT(1), 
    '''          0x81,0x02,          //HID_INPUT(Data_Var_Abs),
    '''
    '''          // Output report (device-receives)
    '''          0x09,0xA9,          //HID_USAGE (vendor_defined)
    '''          0x15,0x4B,          //HID_LOGICAL_MIN_8(75),   // minimum 75 milliseconds
    '''          0x25,0xFF,          //HID_LOGICAL_MAX_8(255),  // maximum 255 milliseconds
    '''          0x75,0x08,          //HID_REPORT_SIZE(8), 
    '''          0x95,0x01,          //HID_REPORT_COUNT(1), 
    '''          0x91,0x02,          //HID_OUTPUT(Data_Var_Abs),
    '''
    '''          0xC0                //HID_END_COLLECTION
    ''' </summary>

    Public Class CustomSensor

        Public Class Device
            Public Const Vid As UInt16 = &H16C0
            Public Const Pid As UInt16 = &H12
            Public Const UsagePage As UInt16 = &HFF55
            Public Const UsageId As UInt16 = &HA5
        End Class
    End Class
End Namespace
