'*********************************************************
'
' Copyright (c) Microsoft. All rights reserved.
'
'*********************************************************

Imports System.Globalization
Imports System.Runtime.InteropServices.WindowsRuntime
Imports System.Threading.Tasks
Imports Windows.Storage.Streams
Imports Windows.UI.Xaml
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml.Navigation
Imports SDKTemplate
Imports System.Collections.Generic
Imports Windows.Devices.HumanInterfaceDevice
Imports Windows.Foundation

Namespace CustomTemperatureSensor
    ''' <summary>
    ''' This scenario demonstrates how to send output reports
    ''' </summary>
    Partial Public NotInheritable Class ReportInterval
        Inherits SDKTemplate.Common.LayoutAwarePage
        ' A pointer back to the main page.  This is needed if you want to call methods in MainPage such
        ' as NotifyUser()
        Private rootPage As MainPage = MainPage.Current

        Public Sub New()
            Me.InitializeComponent()
        End Sub

        ''' <summary>
        ''' Invoked when this page is about to be displayed in a Frame.
        '''
        ''' We will enable/disable parts of the UI if the device doesn't support it.
        ''' </summary>
        ''' <param name="eventArgs">Event data that describes how this page was reached.  The Parameter
        ''' property is typically used to configure the page.</param>
        Protected Overrides Sub OnNavigatedTo(ByVal eventArgs As NavigationEventArgs)
            ' We will disable the scenario that is not supported by the device.
            ' If no devices are connected, none of the scenarios will be shown and an error will be displayed
            Dim deviceScenarios As New Dictionary(Of DeviceType, UIElement)()
            deviceScenarios.Add(DeviceType.CustomSensor, CustomSensorScenario)

            Utilities.SetUpDeviceScenarios(deviceScenarios, DeviceScenarioContainer)
        End Sub

        ''' <summary>
        ''' This method supports a minimum report interval of 75 milliseconds and a maximum report interval of 250 milliseconds.
        ''' </summary>
        ''' <param name="sender"></param>
        ''' <param name="eventArgs"></param>
        Private Async Sub SetReportInterval_Click(ByVal sender As Object, ByVal eventArgs As Windows.UI.Xaml.RoutedEventArgs)
            Dim valueToWrite As Byte = 0

            ButtonSetReportInterval.IsEnabled = False

            If NumericValueToWrite.SelectedIndex = 0 Then
                valueToWrite = 75
            End If
            If NumericValueToWrite.SelectedIndex = 1 Then
                valueToWrite = 100
            End If
            If NumericValueToWrite.SelectedIndex = 2 Then
                valueToWrite = 150
            End If
            If NumericValueToWrite.SelectedIndex = 3 Then
                valueToWrite = 200
            End If
            If NumericValueToWrite.SelectedIndex = 4 Then
                valueToWrite = 250
            End If
            Await SetReportIntervalAsync(valueToWrite)
            ButtonSetReportInterval.IsEnabled = True
        End Sub


        ''' <summary>
        ''' The app sends an output report to the temperature sensor to request a new report interval.
        ''' </summary>
        ''' <param name="valueToWrite"></param>
        ''' <returns>A task that can be used to chain more methods after completing the scenario</returns>
        Private Async Function SetReportIntervalAsync(ByVal valueToWrite As Byte) As Task
            Dim outputReport As HidOutputReport = EventHandlerForDevice.Current.Device.CreateOutputReport()
            Dim dataWriter As DataWriter = New DataWriter()

            'First byte contains the report id
            dataWriter.WriteByte(CType(outputReport.Id, Byte))
            dataWriter.WriteByte(CType(valueToWrite, Byte))
            outputReport.Data = dataWriter.DetachBuffer()
            Dim bytesWritten As IAsyncOperation(Of UInteger) = EventHandlerForDevice.Current.Device.SendOutputReportAsync(outputReport)
            rootPage.NotifyUser("Bytes written:  " & bytesWritten.ToString() & "; Value Written: " & valueToWrite.ToString(), NotifyType.StatusMessage)

        End Function
    End Class
End Namespace
