﻿Imports System.Threading
Imports Microsoft.SPOT
Imports Microsoft.SPOT.Hardware
Imports SecretLabs.NETMF.Hardware
Imports SecretLabs.NETMF.Hardware.Netduino
Imports System.IO.Ports


Namespace NetduinoSensor
	Public Class Program
		Public Shared Sub Main()
			Dim led As New OutputPort(Pins.ONBOARD_LED, False)

            Dim sensor As New Sensor
            'minimum voltage range
            Const minRange As Integer = 0
            ' maximum voltage range in milliVolts
            Const maxRange As Integer = 3300

            Dim voltsPin = New SecretLabs.NETMF.Hardware.AnalogInput(Pins.GPIO_PIN_A0) ' A0 monitors Vout from the LM35
			voltsPin.SetRange(minRange, maxRange) ' The output range is 0 to 3300 milliVolts

			Dim milliVolts As Double = 0.0
			Dim tempC As Double = 0.0
			Dim tempF As Double = 0.0
			Dim simpleTemp As Integer = 0 ' We return an integer temperature in the input report
			Dim CurrentInterval As Integer = 250 ' 250 millisecond intervals is our default
			Dim RequestedInterval As Integer = 0 ' received from host
			Dim i As Integer = 0 ' loop counter
			Dim tempArray() As Integer = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0} 'used to record the last twelve readings
			Dim currentTemp As Integer = 0 ' most recent reading
			Dim firstReading As Boolean = True

			' We pause for 5 seconds after invokng Open to ensure that
			' the method has completed.
			If sensor.Open() Then
				For i = 0 To 4
					led.Write(True)
					Thread.Sleep(1000)
					led.Write(False)
				Next i
			End If

			Do
				' Retrieve the current temperature reading

				milliVolts = CDbl(voltsPin.Read()) ' Read returns a value in the specified range
				tempC = milliVolts / 10.0 ' Sensor returns 10mV per degree Centigrade
				tempF = 1.8 * tempC + 32 'Convert to degrees Fahrenheit
                simpleTemp = CInt(tempF)

				' Because there are voltage fluctuations when the external
				' power supply is connected to the Netduino, we use a running
				' average to "smooth" the values.

				If firstReading Then
					firstReading = False
					currentTemp = simpleTemp
					For i = 0 To 11
						tempArray(i) = simpleTemp
					Next i

				Else
					tempArray = Shift(simpleTemp, tempArray) ' Shift the array elements and insert the new temp
					currentTemp = Average(tempArray) ' Compute a running average of the last 12 readings
				End If

				RequestedInterval = sensor.Update(currentTemp, CurrentInterval)

				' Check for a possible new interval requested via an
				' output report.

				If RequestedInterval <> 0 Then
					 CurrentInterval = RequestedInterval
				End If

				led.Write(True)
				Thread.Sleep(CurrentInterval)
				led.Write(False)
			Loop
		End Sub

		' This method shifts the elements of the temperature array left 
		' and then inserts the new temperature-reading into the last (or 12th) slot
		' It returns the updated array.

		Private Shared Function Shift(ByVal temperature As Integer, ByVal tempArray() As Integer) As Integer()
			Dim i As Integer = 0

			' Shift array contents left by one element
			For i = 0 To (tempArray.Length - 1) - 1
				tempArray(i) = tempArray(i + 1)
			Next i
			tempArray(tempArray.Length - 1) = temperature

			Return tempArray
		End Function

		

		Private Shared Function Average(ByVal tempArray() As Integer) As Integer
			Dim i As Integer = 0
			Dim currentTemp As Integer = 0

			' Sum the temperatures in the array
			For i = 0 To tempArray.Length - 1
				currentTemp += tempArray(i)
			Next i

            'Compute the average reading
			currentTemp = currentTemp \ 12

			' Return the average reading
			Return currentTemp
		End Function
	End Class
End Namespace
